Struct bitmask_core::data::structs::BlindingUtxo
source · pub struct BlindingUtxo {
pub conceal: String,
pub blinding: String,
pub utxo: OutPoint,
}Expand description
A blinded UTXO is an outpoint (txid:vout) that has an associated blinding factor to be kept track of separately.
Fields
conceal: StringAn encoded blinded UTXO. Sort of like an RGB address used to receive assets.
Example: "txob1gv9338jucjwledjqel62gg5nxy2kle5r2dk255ky3reevtjsx00q3nf3fe"
blinding: String64-bit blinding factor to reveal assets sent to the blinded UTXO. Helps with privacy.
Example: "8394351521931962961"
utxo: OutPointOutpoint struct